@@ -3,15 +3,21 @@ package Sah::Schema::firefox::local_profile_name;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-06-13'; # DATE
+our $DATE = '2023-06-14'; # DATE
 our $DIST = 'Sah-Schemas-Firefox'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 # TODO: allow selecting local Firefox installation
 
 our $schema = ["firefox::profile_name" => {
     summary => 'Firefox profile name, must exist in local Firefox installation',
     prefilters => ['Firefox::check_profile_name_exists'],
+    description => <<'_',
+
+This is like the `firefox::profile_name` schema, but adds a check (in
+`prefilter` clause) that the profile must exist in local Firefox installation.
+
+_
     examples => [
         {
             value   => '',
@@ -19,7 +25,7 @@ our $schema = ["firefox::profile_name" => {
             test    => 0,
         },
         {
-            summary => 'Assuming the default profile name exists in local Firefox installation',
+            summary => 'Assuming the profile named "default" exists in local Firefox installation',
             value   => 'default',
             valid   => 1,
             test    => 0,
@@ -42,7 +48,7 @@ Sah::Schema::firefox::local_profile_name - Firefox profile name, must exist in l
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::firefox::local_profile_name (from Perl distribution Sah-Schemas-Firefox), released on 2023-06-13.
+This document describes version 0.008 of Sah::Schema::firefox::local_profile_name (from Perl distribution Sah-Schemas-Firefox), released on 2023-06-14.
 
 =head1 SYNOPSIS
 
@@ -50,7 +56,7 @@ This document describes version 0.007 of Sah::Schema::firefox::local_profile_nam
 
  ""  # INVALID
 
- "default"  # valid (Assuming the default profile name exists in local Firefox installation)
+ "default"  # valid (Assuming the profile named "default" exists in local Firefox installation)
 
 =head2 Using with Data::Sah
 
@@ -180,6 +186,11 @@ To create a type constraint and type library from a schema:
  use My::Types qw(FirefoxLocalProfileName);
  FirefoxLocalProfileName->assert_valid($data);
 
+=head1 DESCRIPTION
+
+This is like the C<firefox::profile_name> schema, but adds a check (in
+C<prefilter> clause) that the profile must exist in local Firefox installation.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Firefox>.
