@@ -3,13 +3,19 @@ package Sah::Schema::firefox::local_profile_name::default_first;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-06-13'; # DATE
+our $DATE = '2023-06-14'; # DATE
 our $DIST = 'Sah-Schemas-Firefox'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = ["firefox::local_profile_name" => {
     summary => 'Firefox profile name, must exist in local Firefox installation, default to first',
     'x.perl.default_value_rules' => ['Firefox::first_local_profile_name'],
+    description => <<'_',
+
+This is like `firefox::local_profile_name` schema, but adds a default value rule
+to pick the first profile in the local Firefox installation.
+
+_
     examples => [
         {
             value   => '',
@@ -40,7 +46,7 @@ Sah::Schema::firefox::local_profile_name::default_first - Firefox profile name,
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::firefox::local_profile_name::default_first (from Perl distribution Sah-Schemas-Firefox), released on 2023-06-13.
+This document describes version 0.008 of Sah::Schema::firefox::local_profile_name::default_first (from Perl distribution Sah-Schemas-Firefox), released on 2023-06-14.
 
 =head1 SYNOPSIS
 
@@ -178,6 +184,11 @@ To create a type constraint and type library from a schema:
  use My::Types qw(FirefoxLocalProfileNameDefaultFirst);
  FirefoxLocalProfileNameDefaultFirst->assert_valid($data);
 
+=head1 DESCRIPTION
+
+This is like C<firefox::local_profile_name> schema, but adds a default value rule
+to pick the first profile in the local Firefox installation.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Firefox>.
